==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_fields/JOBSETUPID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour JOBSETUPID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="JOBSETUPID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}JOBCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SCJCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "JOBSETUPID_Type", propOrder = {
    "jobcode",
    "scjcode",
    "description"
})
public class JOBSETUPID_Type {

    @XmlElement(name = "JOBCODE", required = true)
    protected String jobcode;
    @XmlElement(name = "SCJCODE", required = true)
    protected String scjcode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Obtient la valeur de la propriété jobcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getJOBCODE() {
        return jobcode;
    }

    /**
     * Définit la valeur de la propriété jobcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setJOBCODE(String value) {
        this.jobcode = value;
    }

    /**
     * Obtient la valeur de la propriété scjcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSCJCODE() {
        return scjcode;
    }

    /**
     * Définit la valeur de la propriété scjcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSCJCODE(String value) {
        this.scjcode = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/JOBSETUPID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for JOBSETUPID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="JOBSETUPID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}JOBCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SCJCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "JOBSETUPID_Type", propOrder = {
    "jobcode",
    "scjcode",
    "description"
})
public class JOBSETUPID_Type {

    @XmlElement(name = "JOBCODE", required = true)
    protected String jobcode;
    @XmlElement(name = "SCJCODE", required = true)
    protected String scjcode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the jobcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getJOBCODE() {
        return jobcode;
    }

    /**
     * Sets the value of the jobcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setJOBCODE(String value) {
        this.jobcode = value;
    }

    /**
     * Gets the value of the scjcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSCJCODE() {
        return scjcode;
    }

    /**
     * Sets the value of the scjcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSCJCODE(String value) {
        this.scjcode = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}
